// 
// The Waveset SPML General License 
// 
// Version 0.1, April 2003
// Copyright (C) 2003 Waveset Technologies, Inc..
// 6034 West Courtyard Drive, Suite 210, Austin, Texas 78730
// All rights reserved.
// 
// TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions, and the disclaimers in Sections 6
//    and 7 below.
// 
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the disclaimers in Sections 6
//    and 7 below in the documentation and/or other materials provided
//    with the distribution.
// 
// 3. The end-user documentation included with the redistribution, if
//    any, must include the following acknowledgment:
// 
//    "This product includes software developed by 
//     Waveset Technologies, Inc. (www.waveset.com)."
// 
//    Alternately, this acknowledgment may appear in the software itself, if
//    and wherever such third-party acknowledgments normally appear.
//  
// 4. The names "Waveset" and "Waveset Technologies, Inc." must not be
//    used to endorse or promote products derived from this software
//    without the prior written permission of Waveset. For written
//    permission, please contact www.waveset.com.
//  
// 5. Products derived from this software may not be called "Waveset",
//    nor may "Waveset" appear in their name, without the prior written
//    permission of Waveset.
//  
// 6. NO WARRANTY 
// 
//    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED
//    OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
//    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//    DISCLAIMED.
// 
// 7.  LIMITATION OF LIABILITY
// 
//    IN NO EVENT SHALL THE WAVESET OR ITS LICENSORS BE LIABLE FOR ANY
//    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
//    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
//    GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
//    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
//    IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
//    OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
//    ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 
// End of Terms and Conditions
// ====================================================================
//
// Component Name: org.openspml.browser.BrowserFrame
//
// Author(s): Jeff Larson
//
// Description:
//
// The main frame for the OpenSPML browser application.
//

package org.openspml.browser;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class BrowserFrame extends JFrame {

    public State _state;
    public MainPanel _mainPanel;
    public JPanel _statusBar;

    public static void println(String msg) {
	System.out.println(msg);
    }

    public BrowserFrame() {

	enableEvents(AWTEvent.WINDOW_EVENT_MASK);
	try {
            // here is where common state and most "controller" operations are
            // encapsulated
            _state = new State(this);

	    initComponents();
	}
	catch(Exception e) {
	    e.printStackTrace();
	}
    }

    private void initComponents() throws Exception  {

	JPanel contentPane = (JPanel)getContentPane();
	contentPane.setLayout(new BorderLayout());
	contentPane.setPreferredSize(new Dimension(400, 600));

	ImageIcon spmlIcon = new ImageIcon(BrowserFrame.class.getResource("openSpml.gif"));
	setIconImage(spmlIcon.getImage());

	setSize(new Dimension(1000, 700));
	setTitle("OpenSPML Browser");

        JMenuBar menuBar = new JMenuBar();
	this.setJMenuBar(menuBar);

        // File menu

        JMenu menu = new JMenu();
        menuBar.add(menu);
        menu.setText("File");

        // File->Exit
        JMenuItem item = new JMenuItem();
        menu.add(item);
        item.setText("Exit");
	item.addActionListener(new ActionListener()  {
		public void actionPerformed(ActionEvent e) {
                    System.exit(0);
		}
	    });

        // File->SOAP Trace
        item = new JMenuItem();
        menu.add(item);
        item.setText("SOAP Trace");
	item.addActionListener(new ActionListener()  {
		public void actionPerformed(ActionEvent e) {
                    _state.soapTrace();
		}
	    });

        // Help menu
        menu = new JMenu();
        menu.setText("Help");
        menuBar.add(menu);

        // Help->About
        item = new JMenuItem();
        menu.add(item);
        item.setText("About");
	item.addActionListener(new ActionListener()  {
		public void actionPerformed(ActionEvent e) {
                    menuAbout();
		}
	    });
        
	_statusBar = new JPanel();
	_statusBar.setLayout(new BorderLayout());

        _mainPanel = new MainPanel(_state);

	contentPane.add(_statusBar, BorderLayout.SOUTH);
	contentPane.add(_mainPanel, BorderLayout.CENTER);
    }

    /**
     * Help | About action performed
     */
    public void menuAbout() {

	BrowserAboutBox dlg = new BrowserAboutBox(this);
	Dimension dlgSize = dlg.getPreferredSize();
	Dimension frmSize = getSize();
	Point loc = getLocation();
	dlg.setLocation((frmSize.width - dlgSize.width) / 2 + loc.x, (frmSize.height - dlgSize.height) / 2 + loc.y);
	dlg.setModal(true);
	dlg.show();
    }

    /**
     * Overridden so we can exit when window is closed
     */
    protected void processWindowEvent(WindowEvent e) {
	super.processWindowEvent(e);
	if (e.getID() == WindowEvent.WINDOW_CLOSING) {
	    System.exit(0);
	}
    }

}
