// 
// The Waveset SPML General License 
// 
// Version 0.1, April 2003
// Copyright (C) 2003 Waveset Technologies, Inc..
// 6034 West Courtyard Drive, Suite 210, Austin, Texas 78730
// All rights reserved.
// 
// TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions, and the disclaimers in Sections 6
//    and 7 below.
// 
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the disclaimers in Sections 6
//    and 7 below in the documentation and/or other materials provided
//    with the distribution.
// 
// 3. The end-user documentation included with the redistribution, if
//    any, must include the following acknowledgment:
// 
//    "This product includes software developed by 
//     Waveset Technologies, Inc. (www.waveset.com)."
// 
//    Alternately, this acknowledgment may appear in the software itself, if
//    and wherever such third-party acknowledgments normally appear.
//  
// 4. The names "Waveset" and "Waveset Technologies, Inc." must not be
//    used to endorse or promote products derived from this software
//    without the prior written permission of Waveset. For written
//    permission, please contact www.waveset.com.
//  
// 5. Products derived from this software may not be called "Waveset",
//    nor may "Waveset" appear in their name, without the prior written
//    permission of Waveset.
//  
// 6. NO WARRANTY 
// 
//    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED
//    OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
//    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//    DISCLAIMED.
// 
// 7.  LIMITATION OF LIABILITY
// 
//    IN NO EVENT SHALL THE WAVESET OR ITS LICENSORS BE LIABLE FOR ANY
//    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
//    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
//    GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
//    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
//    IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
//    OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
//    ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 
// End of Terms and Conditions
// ====================================================================
//
// Component Name: org.openspml.message.AddRequest
//
// Author(s): Jeff Larson
//
// Description:
//
// Memory representation for an SPML SearchRequest <filter> element.
//
//

package org.openspml.message;

import java.util.*;
import org.openspml.util.*;


/**
 * Memory representation for the <code>filter</code> element found
 * within a <code>searchRequest</code> message.
 * <p>
 * This is essentially just a list of filter expression terms
 * represented by the <code>FilterTerm</code> class.
 */
public class Filter {

    //////////////////////////////////////////////////////////////////////
    //
    // Fields
    //
    //////////////////////////////////////////////////////////////////////

    static final String ELEMENT = "filter";

    /**
     * List of FilterTerm objects.
     */
    List _terms;

    //////////////////////////////////////////////////////////////////////
    //
    // Construtors
    //
    //////////////////////////////////////////////////////////////////////

    public Filter() {
    }

    Filter(XmlElement e) {
        parseXml(e);
    }

    public void setTerms(List l) {
        _terms = l;
    }

    public void addTerm(FilterTerm ft) {
        if (_terms == null)
            _terms = new ArrayList();
        _terms.add(ft);
    }

    //////////////////////////////////////////////////////////////////////
    //
    // Accessors
    //
    //////////////////////////////////////////////////////////////////////

    public List getTerms() {
        return _terms;
    }

    //////////////////////////////////////////////////////////////////////
    //
    // XML
    //
    //////////////////////////////////////////////////////////////////////

    public void toXml(SpmlBuffer b) {

        // Note that the schema was corrected after initial publication
        // to use the dsml prefix here.

        b.addStartTag("dsml", ELEMENT);
        b.incIndent();

        if (_terms != null) {
            Iterator it = _terms.iterator();
            while (it.hasNext()) {
                FilterTerm term = (FilterTerm)it.next();
                term.toXml(b);
            }
        }

        b.decIndent();
        b.addEndTag("dsml", ELEMENT);
    }

    void parseXml(XmlElement e) {

        for (XmlElement child = e.getChildElement() ;  
             child != null ; child = child.next()) {

            addTerm(new FilterTerm(child));
        }
    }


}
