// 
// The Waveset SPML General License 
// 
// Version 0.1, April 2003
// Copyright (C) 2003 Waveset Technologies, Inc..
// 6034 West Courtyard Drive, Suite 210, Austin, Texas 78730
// All rights reserved.
// 
// TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions, and the disclaimers in Sections 6
//    and 7 below.
// 
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the disclaimers in Sections 6
//    and 7 below in the documentation and/or other materials provided
//    with the distribution.
// 
// 3. The end-user documentation included with the redistribution, if
//    any, must include the following acknowledgment:
// 
//    "This product includes software developed by 
//     Waveset Technologies, Inc. (www.waveset.com)."
// 
//    Alternately, this acknowledgment may appear in the software itself, if
//    and wherever such third-party acknowledgments normally appear.
//  
// 4. The names "Waveset" and "Waveset Technologies, Inc." must not be
//    used to endorse or promote products derived from this software
//    without the prior written permission of Waveset. For written
//    permission, please contact www.waveset.com.
//  
// 5. Products derived from this software may not be called "Waveset",
//    nor may "Waveset" appear in their name, without the prior written
//    permission of Waveset.
//  
// 6. NO WARRANTY 
// 
//    THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED
//    OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
//    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//    DISCLAIMED.
// 
// 7.  LIMITATION OF LIABILITY
// 
//    IN NO EVENT SHALL THE WAVESET OR ITS LICENSORS BE LIABLE FOR ANY
//    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
//    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
//    GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
//    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
//    IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
//    OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
//    ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 
// End of Terms and Conditions
// ====================================================================
//
// Component Name: org.openspml.message.ProviderIdentifier
//
// Author(s): Jeff Larson
//
// Description:
//
// Memory representation for a <providerIdentifier> element.
//
//

package org.openspml.message;

import java.util.*;
import org.openspml.util.*;

/**
 * A class used to represent a <code>providerIdentifier</code> element 
 * used with <code>extendedRequest</code> and <code>schemaRequest</code>
 * messages.
 */
public class ProviderIdentifier implements Constants {

    static final String ELEMENT = "providerIdentifier"; 

    public static final String TYPE_URN = 
    ENUM_PREFIX + "URN";

    public static final String TYPE_OID = 
    ENUM_PREFIX + "OID";

    /**
     * Defined in the schema as xsd:anyType.
     * Here, we'll assume its a string.
     */
    String _id;

    /**
     * One of the id type constants.
     */
    String _type;

    public ProviderIdentifier() {
    }

    public ProviderIdentifier(String s) {
        _id = s;
        _type = TYPE_OID;
    }

    public ProviderIdentifier(XmlElement e) {
        parseXml(e);
    }

    public void setId(String s) {
        _id = s;
    }

    public void setType(String s) {
        _type = s;
    }

    public String getId() {
        return _id;
    }

    public String getType() {
        return _type;
    }

    void toXml(SpmlBuffer b) {

        b.addOpenStartTag(ELEMENT);

        // this is required, to default if necessary
        String t = (_type != null) ? _type : TYPE_OID;
        b.addAttribute("providerIDType", t);

        b.closeStartTag();
        b.incIndent();
        
        if (_id != null)
            b.addElement("providerID", _id);
        
        b.decIndent();
        b.addEndTag(ELEMENT);
    }

    void parseXml(XmlElement e) {

        _type = e.getAttribute("providerIDType");

        XmlElement idel = e.getChildElement();
        if (idel != null) {
            // !! in theory, we should allow any arbitrary
            // identiifer element here, assume for now
            // it will be a string
            _id = idel.getContent();
        }
    }

}

